@@ -521,23 +521,24 @@ and https://debbugs.gnu.org/cgi/bugreport.cgi?bug=34341.")
                  (payload    (ghub--handle-response-payload req))
                  (payload    (ghub--handle-response-error status payload req))
                  (value      (ghub--handle-response-value payload req))
+                 (prev       (ghub--req-url req))
                  (next       (cdr (assq 'next (ghub-response-link-relations
                                                req headers payload)))))
             (when (numberp unpaginate)
               (cl-decf unpaginate))
+            (setf (ghub--req-url req)
+                  (url-generic-parse-url next))
+            (setf (ghub--req-unpaginate req) unpaginate)
             (or (and next
                      unpaginate
                      (or (eq unpaginate t)
                          (>  unpaginate 0))
-                     (progn
-                       (setf (ghub--req-unpaginate req) unpaginate)
-                       (setf (ghub--req-url req)
-                             (url-generic-parse-url next))
-                       (ghub-continue req)))
+                     (ghub-continue req))
                 (let ((callback  (ghub--req-callback req))
                       (errorback (ghub--req-errorback req))
                       (err       (plist-get status :error)))
                   (cond ((and err errorback)
+                         (setf (ghub--req-url req) prev)
                          (funcall (if (eq errorback t)
                                       'ghub--errorback
                                     errorback)
